```     
        <re-input-container class='re-input-invalid'>
          <label>Email</label>
          <re-input required></re-input>
          <span class="re-error">error text</span>
        </re-input-container>
```
```
    <re-input-container>
        <label>New Password</label>
        <re-input required name="password" type="password"></re-input>
        <span class="re-error">error</span>
    </re-input-container>
```
